@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-FS RDF storage
+FS Pairtree-RDF storage
 ==============
 
 Conventions used:
@@ -15,7 +15,7 @@ gives
 
 physical directory for id = "storage/01/02/03/04/05"
 
-FS convention:
+FS convention for versionable items:
 
 {id_path}/_ROOT/_XXXX => Object RDF for this ID
 {id_path}/_MANIFEST/_XXXX => Manifest RDF for this ID
@@ -24,6 +24,9 @@ FS convention:
 {id_path}/_3/_XXXX => Object RDF for this ID, subpart 3
 
 XXXX is just an autoincrementing number - largest is the latest.
+
+# TODO - add a simple method to view version numbers, and delete them
+# deletion will retain the sequence of course.
 """
         
 import os, sys
@@ -32,7 +35,7 @@ import codecs
 
 from rdfobject import RDFobject
 
-from storage_exceptions import ObjectNotFoundException, ObjectAlreadyExistsException
+from storage_exceptions import ObjectNotFoundException, ObjectAlreadyExistsException, NotAPairtreeStoreException
 
 from rdfobject.constructs import Manifest, ItemAlreadyExistsException, ItemDoesntExistException
 
@@ -48,8 +51,8 @@ STORAGE_DIR = "./rdffilestore"
 SPECIAL_FILE_PREFIX = "."
 
 class FileStorageFactory(object):
-    def get_store(self, uri_base=URI_BASE, store_dir=STORAGE_DIR, prefix=SPECIAL_FILE_PREFIX):
-        return FileStorageClient(uri_base, store_dir, prefix)
+    def get_store(self, uri_base=URI_BASE, store_dir=STORAGE_DIR, prefix=SPECIAL_FILE_PREFIX, shorty_length):
+        return FileStorageClient(uri_base, store_dir, prefix, shorty_length)
 
 class FileStorageObject(object):
     def __init__(self, id, fs_store_client):
@@ -101,12 +104,13 @@ class FileStorageObject(object):
         
         
 class FileStorageClient(object):
-    def __init__(self, uri_base, store_dir, prefix):
+    def __init__(self, uri_base, store_dir, prefix, shorty_length):
         self.store_dir = store_dir
         self.uri_base = Namespace(uri_base)
         self.ids = {}
         self.id_parts = {}
         self.prefix = prefix
+        self.shorty_length = shorty_length
         self._init_store()
         
     def _get_id_from_dirpath(self, dirpath):
@@ -131,8 +135,8 @@ class FileStorageClient(object):
     def _id_to_dirpath(self, id):
         dirpath = self.store_dir
         while id:
-            dirpath = os.path.join(dirpath, id[:2])
-            id = id[2:]
+            dirpath = os.path.join(dirpath, id[:self.shorty_length])
+            id = id[self.shorty_length:]
         return dirpath
     
     def _init_store(self):
@@ -144,18 +148,27 @@ class FileStorageClient(object):
             f = open(os.path.join(self.store_dir, "pairtree_prefix"),"w")
             f.write(self.uri_base)
             f.close()
-        elif os.path.exists(os.path.join(self.store_dir, "pairtree_prefix")):
-            """Read the uri base of this store"""
-            f = open(os.path.join(self.store_dir, "pairtree_prefix"),"r")
-            prefix = f.read().strip()
-            f.close()
-            self.uri_base = Namespace(prefix)
+        else:
+            if os.path.exists(os.path.join(self.store_dir, "pairtree_version0_1")):
+                """Seems to be a pairtree0_1 compliant 'store'"""
+                if os.path.exists(os.path.join(self.store_dir, "pairtree_prefix")):
+                    """Read the uri base of this store"""
+                    f = open(os.path.join(self.store_dir, "pairtree_prefix"),"r")
+                    prefix = f.read().strip()
+                    f.close()
+                    self.uri_base = Namespace(prefix)
+            else:
+                raise NotAPairtreeStoreException
             
         if not os.path.isdir(self.store_dir):
-            raise Exception
+            raise NotAPairtreeStoreException
         # load existing objects from the peartree
         for dirpath, dirnames, filenames in os.walk(self.store_dir):
-            if "MANIFEST" in filenames:
+            leaf = False
+            for filename in [x for x in filenames if not x.startswith('pairtree')]:
+                if len(filename) > self.shorty_length:
+                    leaf = True
+            if leaf:
                 this_id = self._get_id_from_dirpath(dirpath)
                 self.ids[this_id] = dirpath
                 self.id_parts[this_id] = dirnames
@@ -164,9 +177,6 @@ class FileStorageClient(object):
         dirpath = self._id_to_dirpath(id)
         if not os.path.exists(dirpath):
             os.makedirs(dirpath)
-            f = open(os.path.join(dirpath, u'MANIFEST'), 'w')
-            f.write(u'rdffilestore object'.encode('utf-8'))
-            f.close()
             os.mkdir(os.path.join(dirpath, u'%sROOT' % self.prefix))
             os.mkdir(os.path.join(dirpath, u'%sMANIFEST' % self.prefix))
             # Setup the root object with a datestamp
@@ -199,7 +209,7 @@ class FileStorageClient(object):
         current_version, current_path = self._get_latest_part(id, self.prefix, part_id)
         version_no = current_version + 1
         f = codecs.open(os.path.join(dirpath, "%s%s" % (self.prefix, version_no)), encoding='utf-8', mode='w')
-        print "Writing to: %s" % (os.path.join(dirpath, "%s%s" % (self.prefix, version_no)))
+        # print "Writing to: %s" % (os.path.join(dirpath, "%s%s" % (self.prefix, version_no)))
         f.write(rdfobject.to_string())
         f.close()
         return version_no
