@@ -6,6 +6,11 @@ class ObjectAlreadyExistsException(Exception):
     """Object ID already exists"""
     pass
     
+class NotAPairtreeStoreException(Exception):
+    """The directory indicated exists, but doesn't 
+    announce itself to be a pairtree store via a
+    'pairtree_version0_1' marker file in the root."""
+    
 class FedoraStoreFailure(Exception):
     """Fedora failed to store or read an item correctly."""
     def __init__(self, resp, content, action):
